@@ -216,7 +216,7 @@ class testing_class():
                 self.print_img_name = False
                 # test all stacks
                 for N in range(len(self.img_list)):
-                    name_list, noise_img, coordinate_list,test_im_name = test_preprocess_chooseOne(self, N)
+                    name_list, noise_img, coordinate_list,test_im_name, img_mean = test_preprocess_chooseOne(self, N)
                     # print(len(name_list))
                     prev_time = time.time()
                     time_start = time.time()
@@ -274,6 +274,8 @@ class testing_class():
                             for id in range(postprocess_turn):
                                 output_patch, raw_patch, stack_start_w, stack_end_w, stack_start_h, stack_end_h, stack_start_s, stack_end_s = multibatch_test_save(
                                     single_coordinate, id, output_image, raw_image)
+                                output_patch=output_patch+img_mean
+                                raw_patch=raw_patch+img_mean
                                 denoise_img[stack_start_s:stack_end_s, stack_start_h:stack_end_h,
                                 stack_start_w:stack_end_w] \
                                     = output_patch * (np.sum(raw_patch) / np.sum(output_patch)) ** 0.5
@@ -283,6 +285,8 @@ class testing_class():
                         else:
                             output_patch, raw_patch, stack_start_w, stack_end_w, stack_start_h, stack_end_h, stack_start_s, stack_end_s = singlebatch_test_save(
                                 single_coordinate, output_image, raw_image)
+                            output_patch=output_patch+img_mean
+                            raw_patch=raw_patch+img_mean
                             denoise_img[stack_start_s:stack_end_s, stack_start_h:stack_end_h, stack_start_w:stack_end_w] \
                                 = output_patch * (np.sum(raw_patch) / np.sum(output_patch)) ** 0.5
                             input_img[stack_start_s:stack_end_s, stack_start_h:stack_end_h, stack_start_w:stack_end_w] \
@@ -298,11 +302,15 @@ class testing_class():
                         print('Displaying the denoise file ----->')
                         display_length = 200
                         test_img_display(output_img, display_length=display_length, norm_min_percent=1,
-                                         norm_max_percent=98)
+                                         norm_max_percent=99)
 
                     # Save inference image
                     if (self.save_test_images_per_epoch):
-                        output_img = output_img.astype('int16')
+                        if output_img.min()<0:
+                             output_img = output_img.astype('int16')
+                        else:
+                             output_img = output_img.astype('uint16')
+                        # output_img = output_img.astype('int16')
                         result_name = output_path_name + '//' + self.img_list[N].replace('.tif','') + '_' + pth_name.replace(
                             '.pth', '') + '_output.tif'
                         io.imsave(result_name, output_img, check_contrast=False)
