@@ -190,9 +190,11 @@ class training_class():
             # Calculate real gap_t
             self.get_gap_t()
             # No preprocessing
-            noise_im = noise_im.astype(np.float32) / self.scale_factor
-            # Minus min before training
-            # noise_im = (noise_im-noise_im.min()).astype(np.float32)/args.scale_factor
+            # noise_im = noise_im.astype(np.float32) / self.scale_factor
+            # Minus mean before training
+            noise_im = noise_im.astype(np.float32)/self.scale_factor
+            noise_im = noise_im-noise_im.mean()
+
             self.noise_im_all.append(noise_im)
             patch_t2 = self.patch_t * 2
             for x in range(0, int((self.whole_y - self.patch_y + self.gap_y) / self.gap_y)):
@@ -328,7 +330,7 @@ class training_class():
                     self.save_model(epoch, iteration)
                     # Start inference using the denoise model at the end of every epoch (optional)
                     if (self.visualize_images_per_epoch | self.save_test_images_per_epoch):
-                        print('Testing epoch {} model on the first noisy file ----->'.format(epoch))
+                        print('Testing epoch {} model on the first noisy file ----->'.format(epoch + 1))
                         self.test(epoch, iteration)
         print('Train finished. Save all models to disk.')
 
